@@ -195,9 +195,11 @@ bool QDateTimeParser::setDigit(QDateTime &v, int index, int newVal) const
         return false;
 
     // Preserve zone:
-    v = (tspec == Qt::TimeZone
-         ? QDateTime(newDate, newTime, v.timeZone())
-         : QDateTime(newDate, newTime, tspec, offset));
+    v =
+#if QT_CONFIG(timezone)
+         tspec == Qt::TimeZone ? QDateTime(newDate, newTime, v.timeZone()) :
+#endif
+         QDateTime(newDate, newTime, tspec, offset);
     return true;
 }
 
@@ -213,7 +215,9 @@ int QDateTimeParser::absoluteMax(int s, const QDateTime &cur) const
 {
     const SectionNode &sn = sectionNode(s);
     switch (sn.type) {
+#if QT_CONFIG(timezone)
     case TimeZoneSection: return QTimeZone::MaxUtcOffsetSecs;
+#endif
     case Hour24Section:
     case Hour12Section: return 23; // this is special-cased in
                                    // parseSection. We want it to be
@@ -248,7 +252,9 @@ int QDateTimeParser::absoluteMin(int s) const
 {
     const SectionNode &sn = sectionNode(s);
     switch (sn.type) {
+#if QT_CONFIG(timezone)
     case TimeZoneSection: return QTimeZone::MinUtcOffsetSecs;
+#endif
     case Hour24Section:
     case Hour12Section:
     case MinuteSection:
@@ -766,9 +772,11 @@ QDateTimeParser::parseSection(const QDateTime &currentValue, int sectionIndex,
             text->replace(offset, used, sectiontext.constData(), used);
         break; }
     case TimeZoneSection:
+#if QT_CONFIG(timezone)
         result = findTimeZone(sectionTextRef, currentValue,
                               absoluteMax(sectionIndex),
                               absoluteMin(sectionIndex));
+#endif
         break;
     case MonthSection:
     case DayOfWeekSectionShort:
@@ -1090,17 +1098,21 @@ QDateTimeParser::scanString(const QDateTime &defaultValue,
     int dayofweek = defaultDate.dayOfWeek();
     Qt::TimeSpec tspec = defaultValue.timeSpec();
     int zoneOffset = 0; // In seconds; local - UTC
+#if QT_CONFIG(timezone)
     QTimeZone timeZone;
+#endif
     switch (tspec) {
     case Qt::OffsetFromUTC: // timeZone is ignored
         zoneOffset = defaultValue.offsetFromUtc();
         break;
+#if QT_CONFIG(timezone)
     case Qt::TimeZone:
         timeZone = defaultValue.timeZone();
         if (timeZone.isValid())
             zoneOffset = timeZone.offsetFromUtc(defaultValue);
         // else: is there anything we can do about this ?
         break;
+#endif
     default: // zoneOffset and timeZone are ignored
         break;
     }
@@ -1125,9 +1137,11 @@ QDateTimeParser::scanString(const QDateTime &defaultValue,
         {
             const QDate date = actualDate(isSet, year, year2digits, month, day, dayofweek);
             const QTime time = actualTime(isSet, hour, hour12, ampm, minute, second, msec);
-            sect = parseSection(tspec == Qt::TimeZone
-                                ? QDateTime(date, time, timeZone)
-                                : QDateTime(date, time, tspec, zoneOffset),
+            sect = parseSection(
+#if QT_CONFIG(timezone)
+                                tspec == Qt::TimeZone ? QDateTime(date, time, timeZone) :
+#endif
+                                QDateTime(date, time, tspec, zoneOffset),
                                 index, pos, input);
         }
 
@@ -1152,7 +1166,7 @@ QDateTimeParser::scanString(const QDateTime &defaultValue,
         case TimeZoneSection:
             current = &zoneOffset;
             if (sect.used > 0) {
-                // Synchronize with what findTimeZone() found:
+#if QT_CONFIG(timezone) // Synchronize with what findTimeZone() found:
                 QStringRef zoneName = input->midRef(pos, sect.used);
                 Q_ASSERT(!zoneName.isEmpty()); // sect.used > 0
                 const QByteArray latinZone(zoneName == QLatin1String("Z")
@@ -1163,6 +1177,9 @@ QDateTimeParser::scanString(const QDateTime &defaultValue,
                        ? Qt::TimeZone
                        : Qt::OffsetFromUTC)
                     : (Q_ASSERT(startsWithLocalTimeZone(zoneName)), Qt::LocalTime);
+#else
+                tspec = Qt::LocalTime;
+#endif
             }
             break;
         case Hour24Section: current = &hour; break;
@@ -1320,9 +1337,11 @@ QDateTimeParser::scanString(const QDateTime &defaultValue,
 
     const QDate date(year, month, day);
     const QTime time(hour, minute, second, msec);
-    return StateNode(tspec == Qt::TimeZone
-                     ? QDateTime(date, time, timeZone)
-                     : QDateTime(date, time, tspec, zoneOffset),
+    return StateNode(
+#if QT_CONFIG(timezone)
+                     tspec == Qt::TimeZone ? QDateTime(date, time, timeZone) :
+#endif
+                     QDateTime(date, time, tspec, zoneOffset),
                      state, padding, conflicts);
 }
 
@@ -1570,6 +1589,7 @@ QDateTimeParser::ParsedSection
 QDateTimeParser::findTimeZone(QStringRef str, const QDateTime &when,
                               int maxVal, int minVal) const
 {
+#if QT_CONFIG(timezone)
     int index = startsWithLocalTimeZone(str);
     int offset;
 
@@ -1612,6 +1632,7 @@ QDateTimeParser::findTimeZone(QStringRef str, const QDateTime &when,
     if (index > 0 && maxVal >= offset && offset >= minVal)
         return ParsedSection(Acceptable, offset, index);
 
+#endif // timezone
     return ParsedSection();
 }
 
